@@ -133,7 +133,7 @@ class S3FileSystem(AsyncFileSystem):
     kwargs : other parameters for core session
     session : aiobotocore AioSession object to be used for all connections.
          This session will be used inplace of creating a new session inside S3FileSystem.
-         For example: aiobotocore.AioSession(profile='test_user')
+         For example: aiobotocore.session.AioSession(profile='test_user')
 
     The following parameters are passed on to fsspec:
 
@@ -214,7 +214,7 @@ class S3FileSystem(AsyncFileSystem):
         self.use_ssl = use_ssl
         self.cache_regions = cache_regions
         self._s3 = None
-        self.session = None
+        self.session = session
 
     @property
     def s3(self):
@@ -375,7 +375,8 @@ class S3FileSystem(AsyncFileSystem):
             config_kwargs["signature_version"] = UNSIGNED
 
         conf = AioConfig(**config_kwargs)
-        self.session = aiobotocore.AioSession(**self.kwargs)
+        if self.session is None:
+            self.session = aiobotocore.session.AioSession(**self.kwargs)
 
         for parameters in (config_kwargs, self.kwargs, init_kwargs, client_kwargs):
             for option in ("region_name", "endpoint_url"):
@@ -684,8 +685,15 @@ class S3FileSystem(AsyncFileSystem):
 
     async def _mkdir(self, path, acl="", create_parents=True, **kwargs):
         path = self._strip_protocol(path).rstrip("/")
+        if not path:
+            raise ValueError
         bucket, key, _ = self.split_path(path)
-        if not key or (create_parents and not await self._exists(bucket)):
+        if await self._exists(bucket):
+            if not key:
+                # requested to create bucket, but bucket already exist
+                raise FileExistsError
+            # else: # do nothing as bucket is already created.
+        elif not key or create_parents:
             if acl and acl not in buck_acls:
                 raise ValueError("ACL not in %s", buck_acls)
             try:
@@ -705,7 +713,7 @@ class S3FileSystem(AsyncFileSystem):
             except ParamValidationError as e:
                 raise ValueError("Bucket create failed %r: %s" % (bucket, e))
         else:
-            # raises if bucket doesn't exist, but doesn't write anything
+            # raises if bucket doesn't exist and doesn't get create flag.
             await self._ls(bucket)
 
     mkdir = sync_wrapper(_mkdir)
