@@ -227,6 +227,15 @@ def test_config_kwargs_class_attributes_override():
     assert s3.connect().meta.config.read_timeout == 120
 
 
+def test_user_session_is_preserved():
+    from aiobotocore.session import get_session
+
+    session = get_session()
+    s3 = S3FileSystem(session=session)
+    s3.connect()
+    assert s3.session == session
+
+
 def test_idempotent_connect(s3):
     first = s3.s3
     assert s3.connect(refresh=True) is not first
@@ -575,6 +584,32 @@ def test_mkdir(s3):
     assert bucket in s3.ls("/")
 
 
+def test_mkdir_existing_bucket(s3):
+    # mkdir called on existing bucket should be no-op and not calling create_bucket
+    # creating a s3 bucket
+    bucket = "test1_bucket"
+    s3.mkdir(bucket)
+    assert bucket in s3.ls("/")
+    # a second call.
+    with pytest.raises(FileExistsError):
+        s3.mkdir(bucket)
+
+
+def test_mkdir_bucket_and_key_1(s3):
+    bucket = "test1_bucket"
+    file = bucket + "/a/b/c"
+    s3.mkdir(file, create_parents=True)
+    assert bucket in s3.ls("/")
+
+
+def test_mkdir_bucket_and_key_2(s3):
+    bucket = "test1_bucket"
+    file = bucket + "/a/b/c"
+    with pytest.raises(FileNotFoundError):
+        s3.mkdir(file, create_parents=False)
+    assert bucket not in s3.ls("/")
+
+
 def test_mkdir_region_name(s3):
     bucket = "test2_bucket"
     s3.mkdir(bucket, region_name="eu-central-1")
@@ -598,6 +633,28 @@ def test_makedirs(s3):
     assert bucket in s3.ls("/")
 
 
+def test_makedirs_existing_bucket(s3):
+    bucket = "test_makedirs_bucket"
+    s3.mkdir(bucket)
+    assert bucket in s3.ls("/")
+    test_file = bucket + "/a/b/c/file"
+    # no-op, and no error.
+    s3.makedirs(test_file)
+
+
+def test_makedirs_pure_bucket_exist_ok(s3):
+    bucket = "test1_bucket"
+    s3.mkdir(bucket)
+    s3.makedirs(bucket, exist_ok=True)
+
+
+def test_makedirs_pure_bucket_error_on_exist(s3):
+    bucket = "test1_bucket"
+    s3.mkdir(bucket)
+    with pytest.raises(FileExistsError):
+        s3.makedirs(bucket, exist_ok=False)
+
+
 def test_bulk_delete(s3):
     with pytest.raises(FileNotFoundError):
         s3.rm(["nonexistent/file"])
@@ -1693,7 +1750,6 @@ def test_requester_pays(s3):
     fn = test_bucket_name + "/myfile"
     s3 = S3FileSystem(requester_pays=True, client_kwargs={"endpoint_url": endpoint_uri})
     assert s3.req_kw["RequestPayer"] == "requester"
-    s3.mkdir(test_bucket_name)
     s3.touch(fn)
     with s3.open(fn, "rb") as f:
         assert f.req_kw["RequestPayer"] == "requester"
